Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(14)

Unified Diff: pkg/analyzer/lib/src/summary/resynthesize.dart

Issue 1619913005: Rename TypeRef to EntityRef. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/lib/src/summary/resynthesize.dart
diff --git a/pkg/analyzer/lib/src/summary/resynthesize.dart b/pkg/analyzer/lib/src/summary/resynthesize.dart
index 098ec1e97a4a844e81d30defc5084a3f8a182f87..8e7f0800676cb0e290ad50a31f1808a7bec2a604 100644
--- a/pkg/analyzer/lib/src/summary/resynthesize.dart
+++ b/pkg/analyzer/lib/src/summary/resynthesize.dart
@@ -262,10 +262,10 @@ class _LibraryResynthesizer {
UnlinkedUnit unlinkedUnit;
/**
* Map from slot id to the corresponding [TypeRef] object for linked types
* (i.e. propagated and inferred types).
*/
- Map<int, TypeRef> linkedTypeMap;
+ Map<int, EntityRef> linkedTypeMap;
/**
* Map of top level elements that have been resynthesized so far. The first
@@ -874,7 +874,7 @@ class _LibraryResynthesizer {
// A slot id of 0 means there is no [DartType] object to build.
return null;
}
- TypeRef type = linkedTypeMap[slot];
+ EntityRef type = linkedTypeMap[slot];
if (type == null) {
// A missing entry in [LinkedUnit.types] means there is no [DartType]
// stored in this slot.
@@ -955,12 +955,12 @@ class _LibraryResynthesizer {
}
/**
* Build a [DartType] object based on a [TypeRef]. This [DartType]
* may refer to elements in other libraries than the library being
* deserialized, so handles are used to avoid having to deserialize other
* libraries in the process.
*/
- DartType buildType(TypeRef type) {
+ DartType buildType(EntityRef type) {
if (type.paramReference != 0) {
// TODO(paulberry): make this work for generic methods.
return currentTypeParameters[
@@ -1168,8 +1168,8 @@ class _LibraryResynthesizer {
void populateUnit(CompilationUnitElementImpl unit, int unitNum) {
linkedUnit = linkedLibrary.units[unitNum];
unlinkedUnit = unlinkedUnits[unitNum];
- linkedTypeMap = <int, TypeRef>{};
- for (TypeRef t in linkedUnit.types) {
+ linkedTypeMap = <int, EntityRef>{};
+ for (EntityRef t in linkedUnit.types) {
linkedTypeMap[t.slot] = t;
}
unitHolder = new ElementHolder();
@@ -262,10 +262,10 @@ class _LibraryResynthesizer {
UnlinkedUnit unlinkedUnit;
/**
- * Map from slot id to the corresponding [TypeRef] object for linked types
+ * Map from slot id to the corresponding [EntityRef] object for linked types
* (i.e. propagated and inferred types).
*/
@@ -955,12 +955,12 @@ class _LibraryResynthesizer {
}
/**
- * Build a [DartType] object based on a [TypeRef]. This [DartType]
+ * Build a [DartType] object based on a [EntityRef]. This [DartType]
* may refer to elements in other libraries than the library being
* deserialized, so handles are used to avoid having to deserialize other

Powered by Google App Engine
This is Rietveld 408576698